@@ -11,7 +11,7 @@ class DatabaseDAO(DAOBase):
     def get_by_tenant(self, tenant):
         sql = """
             select host, porta, nome
-            from config.database
+            from multibanco.database
             where tenant = :tenant;
         """
 
