@@ -1,16 +1,5 @@
-import ptvsd
 import os
-import logging
-import logging_loki
-import sys
-import time
 
-from flask import Flask
-
-# Lendo variáveis de ambiente
-APP_NAME = os.environ['APP_NAME']
-DEBUG = bool(os.getenv('DEBUG', 'False'))
-MOPE_CODE = os.environ['MOPE_CODE']
 
 MULTI_DATABASE_HOST = os.environ['MULTI_DATABASE_HOST']
 MULTI_DATABASE_PASS = os.environ['MULTI_DATABASE_PASS']
